@@ -15,6 +15,7 @@
 
 mod plugin_amqplib;
 mod plugin_curl;
+mod plugin_memcache;
 mod plugin_memcached;
 mod plugin_mongodb;
 mod plugin_mysqli;
@@ -22,6 +23,7 @@ mod plugin_pdo;
 mod plugin_predis;
 mod plugin_redis;
 mod plugin_swoole;
+mod style;
 
 use crate::execute::{AfterExecuteHook, BeforeExecuteHook};
 use once_cell::sync::Lazy;
@@ -43,6 +45,7 @@ static PLUGINS: Lazy<Vec<Box<DynPlugin>>> = Lazy::new(|| {
         Box::<plugin_redis::RedisPlugin>::default(),
         Box::<plugin_amqplib::AmqplibPlugin>::default(),
         Box::<plugin_mongodb::MongodbPlugin>::default(),
+        Box::<plugin_memcache::MemcachePlugin>::default(),
     ]
 });
 
